summaryrefslogtreecommitdiff
path: root/java/util
diff options
context:
space:
mode:
authorEric Blake <ebb9@byu.net>2002-02-24 04:25:15 +0000
committerEric Blake <ebb9@byu.net>2002-02-24 04:25:15 +0000
commita3f60f71365174676e1302f0b201f5772849ffd3 (patch)
tree493dd1be8064241b1d269916046f7c1f1247b603 /java/util
parent70f6e1ec80b4ffc5370564b2710ee194054da42f (diff)
downloadclasspath-a3f60f71365174676e1302f0b201f5772849ffd3.tar.gz
2002-02-23 Eric Blake <ebb9@email.byu.edu>
* java/awt/AWTError.java: Update to 1.4. * java/awt/AWTException.java: Ditto. * java/awt/IllegalComponentStateException.java: Ditto. * java/awt/datatransfer/MimeTypeParseException.java: Ditto. * java/awt/datatransfer/UnsupportedFlavorException.java: Ditto. * java/awt/geom/IllegalPathStateException.java: Ditto. * java/awt/geom/NoninvertibleTransformException.java: Ditto. * java/awt/print/PrinterAbortException.java: Ditto. * java/awt/print/PrinterException.java: Ditto. * java/awt/print/PrinterIOException.java: Ditto. * java/beans/IntrospectionException.java: Ditto. * java/beans/PropertyVetoException.java: Ditto. * java/io/CharConversionException.java: Ditto. * java/io/EOFException.java: Ditto. * java/io/FileNotFoundException.java: Ditto. * java/io/InterruptedIOException.java: Ditto. * java/io/InvalidClassException.java: Ditto. * java/io/InvalidObjectException.java: Ditto. * java/io/IOException.java: Ditto. * java/io/NotActiveException.java: Ditto. * java/io/NotSerializableException.java: Ditto. * java/io/ObjectStreamException.java: Ditto. * java/io/OptionalDataException.java: Ditto. * java/io/StreamCorruptedException.java: Ditto. * java/io/SyncFailedException.java: Ditto. * java/io/UnsupportedEncodingException.java: Ditto. * java/io/UTFDataFormatException.java: Ditto. * java/io/WriteAbortedException.java: Ditto. * java/lang/AbstractMethodError.java: Ditto. * java/lang/ArithmeticException.java: Ditto. * java/lang/ArrayIndexOutOfBoundsException.java: Ditto. * java/lang/ArrayStoreException.java: Ditto. * java/lang/AssertionError.java: Ditto. * java/lang/ClassCastException.java: Ditto. * java/lang/ClassCircularityError.java: Ditto. * java/lang/ClassFormatError.java: Ditto. * java/lang/ClassNotFoundException.java: Ditto. * java/lang/CloneNotSupportedException.java: Ditto. * java/lang/Exception.java: Ditto. * java/lang/ExceptionInInitializerError.java: Ditto. * java/lang/IllegalAccessError.java: Ditto. * java/lang/IllegalAccessException.java: Ditto. * java/lang/IllegalArgumentException.java: Ditto. * java/lang/IllegalMonitorStateException.java: Ditto. * java/lang/IllegalStateException.java: Ditto. * java/lang/IllegalThreadStateException.java: Ditto. * java/lang/IncompatibleClassChangeError.java: Ditto. * java/lang/IndexOutOfBoundsException.java: Ditto. * java/lang/InstantiationError.java: Ditto. * java/lang/InstantiationException.java: Ditto. * java/lang/InternalError.java: Ditto. * java/lang/InterruptedException.java: Ditto. * java/lang/LinkageError.java: Ditto. * java/lang/NegativeArraySizeException.java: Ditto. * java/lang/NoClassDefFoundError.java: Ditto. * java/lang/NoSuchFieldError.java: Ditto. * java/lang/NoSuchFieldException.java: Ditto. * java/lang/NoSuchMethodError.java: Ditto. * java/lang/NoSuchMethodException.java: Ditto. * java/lang/NullPointerException.java: Ditto. * java/lang/NumberFormatException.java: Ditto. * java/lang/OutOfMemoryError.java: Ditto. * java/lang/RuntimeException.java: Ditto. * java/lang/SecurityException.java: Ditto. * java/lang/StackOverflowError.java: Ditto. * java/lang/StringIndexOutOfBoundsException.java: Ditto. * java/lang/ThreadDeath.java: Ditto. * java/lang/UnknownError.java: Ditto. * java/lang/UnsatisfiedLinkError.java: Ditto. * java/lang/UnsupportedClassVersionError.java: Ditto. * java/lang/UnsupportedOperationException.java: Ditto. * java/lang/VerifyError.java: Ditto. * java/lang/VirtualMachineError.java: Ditto. * java/lang/Void.java: Ditto. * java/lang/reflect/InvocationTargetException.java: Ditto. * java/lang/reflect/UndeclaredThrowableException.java: Ditto. * java/net/BindException.java: Ditto. * java/net/ConnectException.java: Ditto. * java/net/MalformedURLException.java: Ditto. * java/net/NoRouteToHostException.java: Ditto. * java/net/ProtocolException.java: Ditto. * java/net/SocketException.java: Ditto. * java/net/UnknownHostException.java: Ditto. * java/net/UnknownServiceException.java: Ditto. * java/rmi/AccessException.java: Ditto. * java/rmi/AlreadyBoundException.java: Ditto. * java/rmi/ConnectException.java: Ditto. * java/rmi/ConnectIOException.java: Ditto. * java/rmi/MarshalException.java: Ditto. * java/rmi/NoSuchObjectException.java: Ditto. * java/rmi/NotBoundException.java: Ditto. * java/rmi/RemoteException.java: Ditto. * java/rmi/RMISecurityException.java: Ditto. * java/rmi/ServerException.java: Ditto. * java/rmi/ServerRuntimeException.java: Ditto. * java/rmi/StubNotFoundException.java: Ditto. * java/rmi/UnexpectedException.java: Ditto. * java/rmi/UnknownHostException.java: Ditto. * java/rmi/UnmarshalException.java: Ditto. * java/rmi/activation/ActivateFailedException.java: Ditto. * java/rmi/activation/ActivationException.java: Ditto. * java/rmi/activation/UnknownGroupException.java: Ditto. * java/rmi/activation/UnknownObjectException.java: Ditto. * java/rmi/server/ExportException.java: Ditto. * java/rmi/server/ServerCloneException.java: Ditto. * java/rmi/server/ServerNotActiveException.java: Ditto. * java/rmi/server/SkeletonMismatchException.java: Ditto. * java/rmi/server/SkeletonNotFoundException.java: Ditto. * java/rmi/server/SocketSecurityException.java: Ditto. * java/security/AccessControlException.java: Ditto. * java/security/DigestException.java: Ditto. * java/security/GeneralSecurityException.java: Ditto. * java/security/InvalidAlgorithmParameterException.java: Ditto. * java/security/InvalidKeyException.java: Ditto. * java/security/InvalidParameterException.java: Ditto. * java/security/KeyException.java: Ditto. * java/security/KeyManagementException.java: Ditto. * java/security/KeyStoreException.java: Ditto. * java/security/NoSuchAlgorithmException.java: Ditto. * java/security/NoSuchProviderException.java: Ditto. * java/security/PrivilegedActionException.java: Ditto. * java/security/ProviderException.java: Ditto. * java/security/SignatureException.java: Ditto. * java/security/UnrecoverableKeyException.java: Ditto. * java/security/acl/AclNotFoundException.java: Ditto. * java/security/acl/LastOwnerException.java: Ditto. * java/security/acl/NotOwnerException.java: Ditto. * java/security/cert/CertificateEncodingException.java: Ditto. * java/security/cert/CertificateException.java: Ditto. * java/security/cert/CertificateExpiredException.java: Ditto. * java/security/cert/CertificateNotYetValidException.java: Ditto. * java/security/cert/CertificateParsingException.java: Ditto. * java/security/cert/CRLException.java: Ditto. * java/security/spec/InvalidKeySpecException.java: Ditto. * java/security/spec/InvalidParameterSpecException.java: Ditto. * java/sql/BatchUpdateException.java: Ditto. * java/sql/DataTruncation.java: Ditto. * java/sql/SQLException.java: Ditto. * java/sql/SQLWarning.java: Ditto. * java/text/ParseException.java: Ditto. * java/util/MissingResourceException.java: Ditto. * java/util/jar/JarException.java: Ditto. * java/util/prefs/BackingStoreException.java: Ditto. * java/util/prefs/InvalidPreferencesFormatException.java: Ditto. * java/util/zip/DataFormatException.java: Ditto. * java/util/zip/ZipException.java: Ditto. * java/awt/Makefile.am (EXTRA_DIST): Add FontFormatException.java and HeadlessException.java. * java/awt/FontFormatException.java: New file. * java/awt/HeadlessException.java: New file. * java/awt/color/Makefile.am (EXTRA_DIST): Add CMMException.java and ProfileDataException.java. * java/awt/color/CMMException.java: New file. * java/awt/color/ProfileDataException.java: New file. * java/awt/image/Makefile.am (EXTRA_DIST): Add ImagingOpException.java and RasterFormatException.java. * java/awt/image/ImagingOpException.java: New file. * java/awt/image/RasterFormatException.java: New file. * java/net/Makefile.am (EXTRA_DIST): Add PortUnreachableException.java, SocketTimeoutException.java and URISyntaxException.java. * java/net/PortUnreachableException.java: New file. * java/net/SocketTimeoutException.java: New file. * java/net/URISyntaxException.java: New file. * java/security/cert/Makefile.am (EXTRA_DIST): Add CertPathBuilderException.java, CertPathValidatorException.java, and CertStoreException.java. * java/security/cert/CertPathBuilderException.java: New file. * java/security/cert/CertPathValidatorException.java: New file. * java/security/cert/CertStoreException.java: New file. * vm/reference/java/lang/Throwable.java (toString): Use getLocalizedMessage(). * ChangeLog: Fix spelling error.
Diffstat (limited to 'java/util')
-rw-r--r--java/util/MissingResourceException.java38
-rw-r--r--java/util/jar/JarException.java19
-rw-r--r--java/util/prefs/BackingStoreException.java83
-rw-r--r--java/util/prefs/InvalidPreferencesFormatException.java94
-rw-r--r--java/util/zip/DataFormatException.java29
-rw-r--r--java/util/zip/ZipException.java30
6 files changed, 196 insertions, 97 deletions
diff --git a/java/util/MissingResourceException.java b/java/util/MissingResourceException.java
index 1618c4f56..47525e55b 100644
--- a/java/util/MissingResourceException.java
+++ b/java/util/MissingResourceException.java
@@ -1,5 +1,5 @@
-/* java.util.MissingResourceException
- Copyright (C) 1998, 1999, 2001 Free Software Foundation, Inc.
+/* MissingResourceException.java -- thrown for a missing resource
+ Copyright (C) 1998, 1999, 2001, 2002 Free Software Foundation, Inc.
This file is part of GNU Classpath.
@@ -38,38 +38,42 @@ exception statement from your version. */
package java.util;
-/* Written using "Java Class Libraries", 2nd edition, ISBN 0-201-31002-3
- * "The Java Language Specification", ISBN 0-201-63451-1
- * plus online API docs for JDK 1.2 beta from http://www.javasoft.com.
- * Status: Believed complete and correct.
- */
-
/**
* This exception is thrown when a resource is missing.
*
- * @see ResourceBundle
* @author Jochen Hoenicke
* @author Warren Levy <warrenl@cygnus.com>
+ * @see ResourceBundle
+ * @since 1.1
+ * @status updated to 1.4
*/
public class MissingResourceException extends RuntimeException
{
+ /**
+ * Compatible with JDK 1.1+.
+ */
private static final long serialVersionUID = -4876345176062000401L;
/**
* The name of the resource bundle requested by user.
+ *
+ * @serial the class name of the resource bundle
*/
- private String className;
+ private final String className;
/**
* The key of the resource in the bundle requested by user.
+ *
+ * @serial the name of the resouce
*/
- private String key;
+ private final String key;
/**
* Creates a new exception, with the specified parameters.
- * @param s the detail message.
- * @param className the name of the resource bundle.
- * @param key the key of the missing resource.
+ *
+ * @param s the detail message
+ * @param className the name of the resource bundle
+ * @param key the key of the missing resource
*/
public MissingResourceException(String s, String className, String key)
{
@@ -80,7 +84,8 @@ public class MissingResourceException extends RuntimeException
/**
* Gets the name of the resource bundle, for which a resource is missing.
- * @return the name of the resource bundle.
+ *
+ * @return the name of the resource bundle
*/
public String getClassName()
{
@@ -90,7 +95,8 @@ public class MissingResourceException extends RuntimeException
/**
* Gets the key of the resource that is missing bundle, this is an empty
* string if the whole resource bundle is missing.
- * @return the name of the resource bundle.
+ *
+ * @return the name of the resource bundle
*/
public String getKey()
{
diff --git a/java/util/jar/JarException.java b/java/util/jar/JarException.java
index c8c0fba37..54291c687 100644
--- a/java/util/jar/JarException.java
+++ b/java/util/jar/JarException.java
@@ -1,5 +1,5 @@
-/* Attributes.java -- exception thrown to indicate an problem with a jar file
- Copyright (C) 2000 Free Software Foundation, Inc.
+/* JarException.java -- thrown to indicate an problem with a jar file
+ Copyright (C) 2000, 2002 Free Software Foundation, Inc.
This file is part of GNU Classpath.
@@ -41,35 +41,34 @@ import java.util.zip.ZipException;
/**
* This exception is thrown to indicate an problem with a jar file.
- * It can be constructed with or without a descriptive message of the problem.
- * <p>
* Note that none of the methods in the java.util.jar package actually declare
* to throw this exception, most just declare that they throw an IOException
* which is super class of JarException.
- *
- * @since 1.2
+ *
* @author Mark Wielaard (mark@klomp.org)
+ * @since 1.2
*/
-
public class JarException extends ZipException
{
- // Constructors
+ /**
+ * Compatible with JDK 1.2+.
+ */
+ private static final long serialVersionUID = 7159778400963954473L;
/**
* Create a new JarException without a descriptive error message.
*/
public JarException()
{
- super();
}
/**
* Create a new JarException with a descriptive error message indicating
* what went wrong. This message can later be retrieved by calling the
* <code>getMessage()</code> method.
- * @see java.lang.Throwable@getMessage()
*
* @param message The descriptive error message
+ * @see #getMessage()
*/
public JarException(String message)
{
diff --git a/java/util/prefs/InvalidPreferencesFormatException.java b/java/util/prefs/InvalidPreferencesFormatException.java
index aa4409ce9..ba06b72fb 100644
--- a/java/util/prefs/InvalidPreferencesFormatException.java
+++ b/java/util/prefs/InvalidPreferencesFormatException.java
@@ -1,5 +1,6 @@
-/* InvalidPreferenceFormatException - Indicates reading prefs from stream failed
- Copyright (C) 2001 Free Software Foundation, Inc.
+/* InvalidPreferencesFormatException - indicates reading prefs from stream
+ failed
+ Copyright (C) 2001, 2002 Free Software Foundation, Inc.
This file is part of GNU Classpath.
@@ -7,7 +8,7 @@ GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.
-
+
GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
@@ -37,38 +38,77 @@ exception statement from your version. */
package java.util.prefs;
+import java.io.ObjectOutputStream;
+import java.io.ObjectInputStream;
+import java.io.NotSerializableException;
+
/**
* Indicates reading prefs from stream failed. Thrown by the
* <code>importPreferences()</code> method when the supplied input stream
* could not be read because it was not in the correct XML format.
*
+ * <p>Note that although this class inherits the Serializable interface, an
+ * attempt to serialize will fail with a <code>NotSerializableException</code>.
+ *
+ * @author Mark Wielaard <mark@klomp.org>
+ * @see Preferences
* @since 1.4
- * @author Mark Wielaard (mark@klomp.org)
+ * @status updated to 1.4
*/
-public class InvalidPreferencesFormatException extends Exception {
+public class InvalidPreferencesFormatException extends Exception
+{
+ /**
+ * Creates a new exception with a descriptive message. The cause remains
+ * uninitialized.
+ *
+ * @param message the message
+ */
+ public InvalidPreferencesFormatException(String message)
+ {
+ super(message);
+ }
+
+ /**
+ * Creates a new exception with the given cause.
+ *
+ * @param cause the cause
+ */
+ public InvalidPreferencesFormatException(Throwable cause)
+ {
+ super(cause);
+ }
- /**
- * Creates a new exception with a descriptive message.
- */
- public InvalidPreferencesFormatException(String message) {
- super(message);
- }
+ /**
+ * Creates a new exception with a descriptive message and a cause.
+ *
+ * @param message the message
+ * @param cause the cause
+ */
+ public InvalidPreferencesFormatException(String message, Throwable cause)
+ {
+ super(message, cause);
+ super(message);
+ }
- /**
- * Creates a new exception with the given cause.
- */
- public InvalidPreferencesFormatException(Throwable cause) {
- // XXX - Use when we have 1.4 Throwable support
- // super(cause);
- super();
- }
+ /**
+ * This class should not be serialized.
+ *
+ * @param o the output stream
+ */
+ private void writeObject(ObjectOutputStream o)
+ {
+ throw new NotSerializableException
+ ("java.util.prefs.InvalidPreferencesFormatException");
+ }
- /**
- * Creates a new exception with a descriptive message and a cause.
- */
- public InvalidPreferencesFormatException(String message, Throwable cause) {
- // XXX - Use when we have 1.4 Throwable support
- // super(message, cause);
- super(message);
- }
+ /**
+ * This class should not be serialized.
+ *
+ * @param i the input stream
+ */
+ private void readObject(ObjectInputStream i)
+ {
+ throw new NotSerializableException
+ ("java.util.prefs.InvalidPreferencesFormatException");
+ }
}
diff --git a/java/util/zip/DataFormatException.java b/java/util/zip/DataFormatException.java
index 28ecef059..e5a948e8a 100644
--- a/java/util/zip/DataFormatException.java
+++ b/java/util/zip/DataFormatException.java
@@ -1,5 +1,5 @@
-/* DataformatException.java - Exception thrown when compressed data is corrupt
- Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
+/* DataformatException.java -- thrown when compressed data is corrupt
+ Copyright (C) 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
This file is part of GNU Classpath.
@@ -37,25 +37,34 @@ exception statement from your version. */
package java.util.zip;
-/* Written using on-line Java Platform 1.2 API Specification.
- * Believed complete and correct.
- */
-
/**
* Exception thrown when compressed data is corrupt.
*
* @author Tom Tromey
* @author John Leuner
- * @since JDK 1.1
+ * @since 1.1
+ * @status updated to 1.4
*/
public class DataFormatException extends Exception
{
- public DataFormatException ()
+ /**
+ * Compatible with JDK 1.1+.
+ */
+ private static final long serialVersionUID = 2219632870893641452L;
+
+ /**
+ * Create an exception without a message.
+ */
+ public DataFormatException()
{
- super();
}
- public DataFormatException (String msg)
+ /**
+ * Create an exception with a message.
+ *
+ * @param msg the message
+ */
+ public DataFormatException(String msg)
{
super(msg);
}
diff --git a/java/util/zip/ZipException.java b/java/util/zip/ZipException.java
index ed02c8564..9130ef296 100644
--- a/java/util/zip/ZipException.java
+++ b/java/util/zip/ZipException.java
@@ -1,5 +1,5 @@
-/* ZipException.java - Exception representing a zip related error
- Copyright (C) 1998, 1999, 2000, 2001 Free Software Foundation, Inc.
+/* ZipException.java - exception representing a zip related error
+ Copyright (C) 1998, 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
This file is part of GNU Classpath.
@@ -37,24 +37,34 @@ exception statement from your version. */
package java.util.zip;
-/* Written using on-line Java Platform 1.2 API Specification.
- * Believed complete and correct.
- */
+import java.io.IOException;
/**
- * Is thrown during the creation or input of a zip file.
+ * Thrown during the creation or input of a zip file.
*
* @author Jochen Hoenicke
* @author Per Bothner
- * @since JDK 1.1
+ * @status updated to 1.4
*/
-public class ZipException extends java.io.IOException
+public class ZipException extends IOException
{
- public ZipException ()
+ /**
+ * Compatible with JDK 1.0+.
+ */
+ private static final long serialVersionUID = 8000196834066748623L;
+
+ /**
+ * Create an exception without a message.
+ */
+ public ZipException()
{
- super();
}
+ /**
+ * Create an exception with a message.
+ *
+ * @param msg the message
+ */
public ZipException (String msg)
{
super(msg);
diff --git a/java/util/prefs/BackingStoreException.java b/java/util/prefs/BackingStoreException.java
index 9977f0e55..84debf318 100644
--- a/java/util/prefs/BackingStoreException.java
+++ b/java/util/prefs/BackingStoreException.java
@@ -1,5 +1,6 @@
-/* BackingStoreException - Chained exception thrown when backing store fails
- Copyright (C) 2001 Free Software Foundation, Inc.
+/* BackingStoreException.java - chained exception thrown when backing store
+ fails
+ Copyright (C) 2001, 2002 Free Software Foundation, Inc.
This file is part of GNU Classpath.
@@ -7,7 +8,7 @@ GNU Classpath is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.
-
+
GNU Classpath is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
@@ -37,31 +38,65 @@ exception statement from your version. */
package java.util.prefs;
+import java.io.ObjectOutputStream;
+import java.io.ObjectInputStream;
+import java.io.NotSerializableException;
+
/**
- * Chained exception thrown when backing store fails.
- * This exception is only thrown from methods that actually have to access
- * the backing store such as <code>clear(), keys(), childrenNames(),
- * nodeExists(), removeNode(), flush(), sync(), exportNode(), exportSubTree()
- * </code>, normal operations do not throw BackingStoreExceptions.
+ * Chained exception thrown when backing store fails. This exception is
+ * only thrown from methods that actually have to access the backing store,
+ * such as <code>clear(), keys(), childrenNames(), nodeExists(), removeNode(),
+ * flush(), sync(), exportNode(), exportSubTree()</code>; normal operations
+ * do not throw BackingStoreExceptions.
*
+ * <p>Note that although this class inherits the Serializable interface, an
+ * attempt to serialize will fail with a <code>NotSerializableException</code>.
+ *
+ * @author Mark Wielaard <mark@klomp.org>
* @since 1.4
- * @author Mark Wielaard (mark@klomp.org)
+ * @status updated to 1.4
*/
-public class BackingStoreException extends Exception {
+public class BackingStoreException extends Exception
+{
+ /**
+ * Creates a new exception with a descriptive message.
+ *
+ * @param message the message
+ */
+ public BackingStoreException(String message)
+ {
+ super(message);
+ }
+
+ /**
+ * Create a new exception with the given cause.
+ *
+ * @param cause the cause
+ */
+ public BackingStoreException(Throwable cause)
+ {
+ super(cause);
+ }
- /**
- * Creates a new exception with a descriptive message.
- */
- public BackingStoreException(String message) {
- super(message);
- }
+ /**
+ * This class should not be serialized.
+ *
+ * @param o the output stream
+ */
+ private void writeObject(ObjectOutputStream o)
+ {
+ throw new NotSerializableException
+ ("java.util.prefs.BackingStoreException");
+ }
- /**
- * Create a new exception with the given cause.
- */
- public BackingStoreException(Throwable cause) {
- // XXX - use when we have 1.4 Throwable support
- // super(cause);
- super();
- }
+ /**
+ * This class should not be serialized.
+ *
+ * @param i the input stream
+ */
+ private void readObject(ObjectInputStream i)
+ {
+ throw new NotSerializableException
+ ("java.util.prefs.BackingStoreException");
+ }
}